@@ -24,8 +24,7 @@ class FileSystemJsonArtifact(Artifact):
             json.dumps(self.data_dict)
         except UnicodeDecodeError:
             if not self.binary:
-                raise Exception("should be marked binary", self.key)
-            self.binary = True
+                raise Exception("artifact %s should be marked binary" % self.key)
 
         if not os.path.isfile(self.filepath()) or os.path.getsize(self.filepath()) == 0:
             f = open(self.filepath(), "w")
@@ -106,6 +105,8 @@ class FileSystemJsonArtifact(Artifact):
     def load(self):
         # Load artifact from the cache.
         if not self.is_cached():
+            if self.additional:
+                print "this is an additional artifact, check the script in which is was supposed to be generated for errors"
             raise Exception("trying to load an artifact %s which isn't cached" % self.key)
 
         f = open(self.meta_filepath(), "r")
