@@ -5,15 +5,25 @@ from inspect import isclass
 from logging.handlers import RotatingFileHandler
 import logging
 import os
+import re
 import shutil
 import sys
 import urllib
 
-EXCLUDED_DIRS = ['.bzr', '.hg', '.git', '.svn', 'ignore', 'filters']
-EXCLUDE_DIR_HELP = """Exclude directories from processing by dexy, only relevant
-if recursing. The directories designated for artifacts, logs and cache are
-automatically excluded, as are %s.
-""" % ", ".join(EXCLUDED_DIRS)
+# Directories with this name should be excluded anywhere
+EXCLUDE_DIRS_ALL_LEVELS = ['.bzr', '.hg', '.git', '.svn']
+
+# Directories with these names should be excluded only at the project root
+EXCLUDE_DIRS_ROOT = ['ignore', 'filters']
+
+EXCLUDE_HELP = """Specify directory names to exclude from processing by dexy.
+Directories with these names will be skipped anywhere in your project.
+The following patterns are automatically excluded anywhere in your project: %s.
+The directories designated for artifacts and logs are automatically excluded,
+and the following directory names are also excluded if they appear at the root
+level of your project: %s.
+Any directory with a file named .nodexy will be skipped, and subdirectories of this will also be skipped.
+""" % (", ".join(EXCLUDE_DIRS_ALL_LEVELS), ", ".join(EXCLUDE_DIRS_ROOT))
 
 def artifact_class(artifact_class_name, log):
     artifact_classes = {}
@@ -69,8 +79,8 @@ def setup_option_parser():
         )
 
         parser.add_argument(
-            '-x', '--exclude-dir',
-            help=EXCLUDE_DIR_HELP,
+            '-x', '--exclude',
+            help=EXCLUDE_HELP,
             nargs='+'
         )
 
@@ -86,8 +96,8 @@ def setup_option_parser():
         option_parser = 'optparse'
         parser = optparse.OptionParser(version="%%prog %s" % VERSION)
         parser.add_option(
-            '-x', '--exclude-dir',
-            help=EXCLUDE_DIR_HELP + ' Separate multiple directories with commas.'
+            '-x', '--exclude',
+            help=EXCLUDE_HELP + ' Separate multiple directories with commas.'
         )
 
     # Remaining options are the same for argparse and optparse
@@ -157,7 +167,7 @@ def setup_option_parser():
     add_option(parser,
         '-c', '--cache-dir',
         default='cache',
-        help='location of cache directory (default: cache)'
+        help='DEPRECATED - does not do anything anymore, will be removed soon'
     )
 
     add_option(parser,
@@ -182,6 +192,13 @@ def setup_option_parser():
         help='Create artifacts and logs directory and generic .dexy file'
         )
 
+    add_option(parser,
+        '--serve',
+        default=False,
+        action='store_true',
+        help='Start a static server within the output directory, will be visible on port 8000. (similar to python -m SimpleHTTPServer)'
+        )
+
     add_option(parser,
         '-g', '--config',
         default='.dexy',
@@ -205,10 +222,10 @@ def setup_option_parser():
     if (option_parser == 'argparse'):
         args = parser.parse_args()
         dir_name = args.dir
-        if args.exclude_dir:
-            exclude_dir = args.exclude_dir
+        if args.exclude:
+            additional_excludes = args.exclude
         else:
-            exclude_dir = []
+            additional_excludes = []
 
     elif (option_parser == 'optparse'):
         (args, argv) = parser.parse_args()
@@ -216,10 +233,10 @@ def setup_option_parser():
             dir_name = '.'
         else:
             dir_name = argv[0]
-        if args.exclude_dir:
-            exclude_dir = args.exclude_dir.split(',')
+        if args.exclude:
+            additional_excludes = args.exclude.split(',')
         else:
-            exclude_dir = []
+            additional_excludes = []
     else:
         raise Exception("unexpected option_parser %s" % option_parser)
 
@@ -281,6 +298,10 @@ def setup_option_parser():
     logfile = os.path.join(args.logs_dir, 'dexy.log')
     handler = RotatingFileHandler(logfile)
     dexy_log.addHandler(handler)
+    if args.setup:
+        # This might be the first time someone has run Dexy,
+        # let them know where the logfile is
+        print "dexy will log debugging information to", logfile
 
     formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
     handler.setFormatter(formatter)
@@ -368,64 +389,101 @@ def setup_option_parser():
             if klass.__doc__:
                 print "   ", klass.__doc__.strip()
 
-    return args, dir_name, exclude_dir, dexy_log
+    return args, dir_name, additional_excludes, dexy_log
 
-
-def dexy_command():
-    args, dir_name, exclude_dir, log = setup_option_parser()
-
-    do_not_process_dirs = EXCLUDED_DIRS
-    do_not_process_dirs += exclude_dir
-    do_not_process_dirs.append(args.artifacts_dir)
-    do_not_process_dirs.append(args.logs_dir)
-    do_not_process_dirs.append(args.cache_dir)
+def setup_controller():
+    args, dir_name, additional_excludes, log = setup_option_parser()
 
     if not args.run_dexy:
-        return
+        return None, args, log
 
-    log.info("running dexy with recurse")
     controller = Controller()
+    controller.dir_name = dir_name
     controller.args = args
     controller.allow_remote = args.dangerous
     controller.artifact_class = args.artifact_class
     controller.artifacts_dir = args.artifacts_dir
-    controller.cache_dir = args.cache_dir
     controller.logs_dir = args.logs_dir
     controller.log = log
     controller.config_file = args.config
     controller.use_local_files = args.local
     controller.find_reporters()
-    for r in controller.reports_dirs:
-        if r:
-            do_not_process_dirs.append(r)
+    controller.additional_excludes = additional_excludes
+
+    return controller, args, log
+
+def dexy_command():
+    controller, args, log = setup_controller()
+
+    if not controller:
+        return False
 
-    log.info("skipping directories named %s" % ", ".join(do_not_process_dirs))
     if args.recurse:
-        for root, dirs, files in os.walk(dir_name):
-            process = True
-            for x in do_not_process_dirs:
-                if root.startswith(x) or root.startswith("./%s" % x):
-                    process = False
-                    break
+        log.info("running dexy with recurse")
+        for dirpath, dirnames, filenames in os.walk(controller.dir_name):
+            process_dir = True
 
-            if not process:
-                log.warn("skipping dir %s" % root)
+            if dirpath == ".":
+                # We only exclude these dirs if they occur at project root level
+                for x in EXCLUDE_DIRS_ROOT:
+                    if x in dirnames:
+                        log.debug("removing %s from list of child dirs %s of %s because it is in EXCLUDE_DIRS_ROOT" % (x, dirnames, dirpath))
+                        dirnames.remove(x)
+
+                for x in [controller.artifacts_dir, controller.logs_dir]:
+                    if x in dirnames:
+                        log.debug("removing %s from list of child dirs %s of %s because it is a dexy dir" % (x, dirnames, dirpath))
+                        dirnames.remove(x)
+
+                for x in controller.reports_dirs:
+                    if x in dirnames:
+                        log.debug("removing %s from list of child dirs %s of %s because it is a dexy report dir" % (x, dirnames, dirpath))
+                        dirnames.remove(x)
+
+
+            for x in EXCLUDE_DIRS_ALL_LEVELS:
+                if x in dirnames:
+                    log.debug("removing %s from list of child dirs %s of %s because it is in EXCLUDE_DIRS_ALL_LEVELS" % (x, dirnames, dirpath))
+                    dirnames.remove(x)
+
+            # If there is a file called .nodexy, this dir and all children are skipped.
+            if os.path.isfile(os.path.join(dirpath, '.nodexy')):
+                log.info("nodexy file found in %s" % dirpath)
+                for d in dirnames:
+                    # Remove all child dirs from processing.
+                    dirnames.remove(d)
+                process_dir = False
+
+            # Now process any additional excludes specified on the command line
+            for x in controller.additional_excludes:
+                pattern = x
+                m = re.match(pattern, dirpath)
+                if not m:
+                    pattern = "./%s" % x
+                    m = re.match(pattern, dirpath)
+                if m:
+                    log.debug("removing %s because it matches pattern %s" % (dirpath, pattern))
+                    for d in dirnames:
+                        # Remove all child dirs from processing.
+                        dirnames.remove(d)
+                    process_dir = False
+                else:
+                    # check if children match pattern
+                    for d in dirnames:
+                        if x == d:
+                            fullpath = os.path.join(dirpath, d)
+                            log.debug("removing %s because it matches pattern %s" % (fullpath, pattern))
+                            dirnames.remove(d)
+
+            if not process_dir:
+                log.warn("skipping dir %s" % dirpath)
             else:
-                log.info("processing dir %s" % root)
-                controller.load_config(root)
+                log.info("processing dir %s" % dirpath)
+                controller.load_config(dirpath)
     else:
         log.info("not recursing")
-        process = True
-        for x in do_not_process_dirs:
-            if dir_name.startswith(x) or dir_name.startswith("./%s" % x):
-                process = False
-                break
-
-        if not process:
-            log.warn("skipping dir %s" % dir_name)
-        else:
-            log.info("processing dir %s" % dir_name)
-            controller.load_config(dir_name)
+        log.info("processing dir %s" % controller.dir_name)
+        controller.load_config(controller.dir_name)
 
     controller.setup_and_run()
     if not args.no_reports:
@@ -434,3 +492,17 @@ def dexy_command():
     else:
         print 'reports not run'
 
+    if args.serve:
+        import SimpleHTTPServer
+        import SocketServer
+
+        os.chdir('output')
+
+        PORT = 8000
+        Handler = SimpleHTTPServer.SimpleHTTPRequestHandler
+
+        httpd = SocketServer.TCPServer(("", PORT), Handler)
+
+        print "serving at port", PORT
+        httpd.serve_forever()
+
