@@ -38,7 +38,7 @@ class LatexHandler(DexyHandler):
         if not latex_bin:
             raise Exception("no executable found for latex")
 
-        command = "%s %s" % (e, latex_filename)
+        command = "%s -interaction=batchmode %s" % (e, latex_filename)
         self.log.info(command)
 
         proc = subprocess.Popen(command, shell=True,
@@ -49,6 +49,9 @@ class LatexHandler(DexyHandler):
 
         stdout, stderr = proc.communicate()
         self.artifact.stdout = stdout
+        if proc.returncode > 0:
+            raise Exception("latex error, look for information in %s" %
+                            latex_filename.replace(".tex", ".log"))
 
         # Run LaTeX again for TOC numbering etc.
         proc = subprocess.Popen(command, shell=True,
@@ -59,6 +62,9 @@ class LatexHandler(DexyHandler):
 
         stdout, stderr = proc.communicate()
         self.artifact.stdout += stdout
+        if proc.returncode > 0:
+            raise Exception("latex error, look for information in %s" %
+                            latex_filename.replace(".tex", ".log"))
 
 class EmbedFonts(DexyHandler):
     INPUT_EXTENSIONS = [".pdf"]
@@ -161,3 +167,31 @@ class ROutputBatchHandler(DexyHandler):
         stdout, stderr = proc.communicate()
         self.artifact.stdout = stdout
         self.artifact.set_data_from_artifact()
+
+class DotHandler(DexyHandler):
+    """
+    Renders .dot files to either PNG or PDF images.
+    """
+    INPUT_EXTENSIONS = [".dot"]
+    OUTPUT_EXTENSIONS = [".png", ".pdf"]
+    EXECUTABLE = 'dot'
+    VERSION = 'dot -V'
+    ALIASES = ['dot', 'graphviz']
+    FINAL = True
+    BINARY = True
+
+    def process(self):
+        self.artifact.generate_workfile()
+        wf = self.artifact.work_filename()
+        af = self.artifact.filename()
+        ex = self.artifact.ext.replace(".", "")
+        command = "%s -T%s -o%s %s" % (self.executable(), ex, af, wf)
+        self.log.info(command)
+        proc = subprocess.Popen(command, shell=True,
+                                cwd=self.artifact.artifacts_dir,
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.STDOUT)
+
+        stdout, stderr = proc.communicate()
+        self.artifact.stdout = stdout
+        self.artifact.set_data_from_artifact()
